@@ -5,7 +5,7 @@ BEGIN {
   use Exporter;
   use vars qw($VERSION @ISA @EXPORT_OK);
 
-  $VERSION = '0.014';
+  $VERSION = '0.016';
   @ISA     = qw(Exporter);
 
   @EXPORT_OK = qw(
@@ -88,7 +88,7 @@ L<File::Media::Sort>, L<File::PatternMatch>, L<flexget(1)>
 
   Magnus Woldrich
   CPAN ID: WOLDRICH
-  magnus@trapd00r.se
+  m@japh.se
   http://japh.se
 
 =head1 CONTRIBUTORS
